@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                      *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #include "ops/copyoperation.h"
 
@@ -33,10 +31,10 @@
 #include "util/capacity.h"
 #include "util/report.h"
 
+#include <QDebug>
 #include <QString>
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 /** Creates a new CopyOperation.
 	@param targetdevice the Device to copy the Partition to
@@ -66,7 +64,7 @@ CopyOperation::CopyOperation(Device& targetdevice, Partition* copiedpartition, D
 	Q_ASSERT(dest);
 
 	if (dest == NULL)
-		kWarning() << "destination partition not found at sector " << copiedPartition().firstSector();
+		qWarning() << "destination partition not found at sector " << copiedPartition().firstSector();
 
 	if (dest && !dest->roles().has(PartitionRole::Unallocated))
 	{
@@ -162,12 +160,12 @@ bool CopyOperation::execute(Report& parent)
 					// if maximizing doesn't work, just warn the user, don't fail
 					if (!maximizeJob()->run(*report))
 					{
-						report->line() << i18nc("@info/plain", "Warning: Maximizing file system on target partition <filename>%1</filename> to the size of the partition failed.", copiedPartition().deviceNode());
+						report->line() << xi18nc("@info/plain", "Warning: Maximizing file system on target partition <filename>%1</filename> to the size of the partition failed.", copiedPartition().deviceNode());
 						warning = true;
 					}
 				}
 				else
-					report->line() << i18nc("@info/plain", "Checking target partition <filename>%1</filename> after copy failed.", copiedPartition().deviceNode());
+					report->line() << xi18nc("@info/plain", "Checking target partition <filename>%1</filename> after copy failed.", copiedPartition().deviceNode());
 			}
 			else
 			{
@@ -184,7 +182,7 @@ bool CopyOperation::execute(Report& parent)
 			report->line() << i18nc("@info/plain", "Creating target partition for copying failed.");
 	}
 	else
-		report->line() << i18nc("@info/plain", "Checking source partition <filename>%1</filename> failed.", sourcePartition().deviceNode());
+		report->line() << xi18nc("@info/plain", "Checking source partition <filename>%1</filename> failed.", sourcePartition().deviceNode());
 
 	if (rval)
 		setStatus(warning ? StatusFinishedWarning : StatusFinishedSuccess);
@@ -201,16 +199,16 @@ QString CopyOperation::updateDescription() const
 	if (overwrittenPartition())
 	{
 		if (copiedPartition().length() == overwrittenPartition()->length())
-			return QString(i18nc("@info/plain", "Copy partition <filename>%1</filename> (%2, %3) to <filename>%4</filename> (%5, %6)",
+			return xi18nc("@info/plain", "Copy partition <filename>%1</filename> (%2, %3) to <filename>%4</filename> (%5, %6)",
 				sourcePartition().deviceNode(),
 				Capacity::formatByteSize(sourcePartition().capacity()),
 				sourcePartition().fileSystem().name(),
 				overwrittenPartition()->deviceNode(),
 				Capacity::formatByteSize(overwrittenPartition()->capacity()),
 				overwrittenPartition()->fileSystem().name()
-			));
+			);
 
-		return QString(i18nc("@info/plain", "Copy partition <filename>%1</filename> (%2, %3) to <filename>%4</filename> (%5, %6) and grow it to %7",
+		return xi18nc("@info/plain", "Copy partition <filename>%1</filename> (%2, %3) to <filename>%4</filename> (%5, %6) and grow it to %7",
 			sourcePartition().deviceNode(),
 			Capacity::formatByteSize(sourcePartition().capacity()),
 			sourcePartition().fileSystem().name(),
@@ -218,26 +216,26 @@ QString CopyOperation::updateDescription() const
 			Capacity::formatByteSize(overwrittenPartition()->capacity()),
 			overwrittenPartition()->fileSystem().name(),
 			Capacity::formatByteSize(copiedPartition().capacity())
-		));
+		);
 	}
 
 	if (copiedPartition().length() == sourcePartition().length())
-		return QString(i18nc("@info/plain", "Copy partition <filename>%1</filename> (%2, %3) to unallocated space (starting at %4) on <filename>%5</filename>",
+		return xi18nc("@info/plain", "Copy partition <filename>%1</filename> (%2, %3) to unallocated space (starting at %4) on <filename>%5</filename>",
 			sourcePartition().deviceNode(),
 			Capacity::formatByteSize(sourcePartition().capacity()),
 			sourcePartition().fileSystem().name(),
 			Capacity::formatByteSize(copiedPartition().firstSector() * targetDevice().logicalSectorSize()),
 			targetDevice().deviceNode()
-		));
+		);
 
-	return QString(i18nc("@info/plain", "Copy partition <filename>%1</filename> (%2, %3) to unallocated space (starting at %4) on <filename>%5</filename> and grow it to %6",
+	return xi18nc("@info/plain", "Copy partition <filename>%1</filename> (%2, %3) to unallocated space (starting at %4) on <filename>%5</filename> and grow it to %6",
 		sourcePartition().deviceNode(),
 		Capacity::formatByteSize(sourcePartition().capacity()),
 		sourcePartition().fileSystem().name(),
 		Capacity::formatByteSize(copiedPartition().firstSector() * targetDevice().logicalSectorSize()),
 		targetDevice().deviceNode(),
 		Capacity::formatByteSize(copiedPartition().capacity())
-	));
+	);
 }
 
 void CopyOperation::setOverwrittenPartition(Partition* p)
